@@ -49,6 +49,7 @@
 #include "gedit-window.h"
 #include "gedit-enum-types.h"
 #include "gedit-settings.h"
+#include "gedit-marshal.h"
 
 #define GEDIT_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_NOTEBOOK, GeditNotebookPrivate))
 
@@ -81,6 +82,7 @@ enum
 enum
 {
 	TAB_CLOSE_REQUEST,
+	SHOW_POPUP_MENU,
 	LAST_SIGNAL
 };
 
@@ -251,29 +253,31 @@ find_tab_num_at_pos (GtkNotebook *notebook,
 }
 
 static gboolean
-gedit_notebook_button_press (GtkWidget *widget,
+gedit_notebook_button_press (GtkWidget      *widget,
                              GdkEventButton *event)
 {
 	GtkNotebook *nb = GTK_NOTEBOOK (widget);
-	gint tab_clicked;
 
-	if (event->type != GDK_BUTTON_PRESS ||
-	    event->button != 3 ||
-	    (event->state & gtk_accelerator_get_default_mod_mask ()) != 0)
+	if (event->type == GDK_BUTTON_PRESS &&
+	    event->button == 3 &&
+	    (event->state & gtk_accelerator_get_default_mod_mask ()) == 0)
 	{
-		return GTK_WIDGET_CLASS (gedit_notebook_parent_class)->button_press_event (widget, event);
+		gint tab_clicked;
+
+		tab_clicked = find_tab_num_at_pos (nb, event->x_root, event->y_root);
+		if (tab_clicked >= 0)
+		{
+			GtkWidget *tab;
+
+			tab = gtk_notebook_get_nth_page (nb, tab_clicked);
+
+			g_signal_emit (G_OBJECT (widget), signals[SHOW_POPUP_MENU], 0, event, tab);
+
+			return TRUE;
+		}
 	}
 
-	tab_clicked = find_tab_num_at_pos (nb, event->x_root, event->y_root);
-	if (tab_clicked < 0)
-	{
-		return GTK_WIDGET_CLASS (gedit_notebook_parent_class)->button_press_event (widget, event);
-	}
-
-	/* switch to the page the mouse is over */
-	gtk_notebook_set_current_page (nb, tab_clicked);
-
-	return TRUE;
+	return GTK_WIDGET_CLASS (gedit_notebook_parent_class)->button_press_event (widget, event);
 }
 
 /*
@@ -527,6 +531,18 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 			      1,
 			      GEDIT_TYPE_TAB);
 
+	signals[SHOW_POPUP_MENU] =
+		g_signal_new ("show-popup-menu",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_FIRST,
+			      G_STRUCT_OFFSET (GeditNotebookClass, show_popup_menu),
+			      NULL, NULL,
+			      gedit_marshal_VOID__BOXED_OBJECT,
+			      G_TYPE_NONE,
+			      2,
+			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
+			      GEDIT_TYPE_TAB);
+
 	g_type_class_add_private (object_class, sizeof (GeditNotebookPrivate));
 }
 
