@@ -163,6 +163,7 @@ gedit_main (gboolean service)
 {
 	GeditPluginsEngine *engine;
 	GeditApp *app;
+	gboolean restored = FALSE;
 	const gchar *dir;
 	gchar *icon_dir;
 
@@ -184,27 +185,19 @@ gedit_main (gboolean service)
 	gedit_debug_message (DEBUG_APP, "Init session manager");
 	gedit_session_init ();
 
-	if (!service)
+	if (!service && gedit_session_is_restored ())
 	{
-		gboolean restored = FALSE;
+		restored = gedit_session_load ();
+	}
 
-		if (gedit_session_is_restored ())
-		{
-			restored = gedit_session_load ();
-		}
-
-		if (!restored)
-		{
-			gedit_main_window ();
-		}
+	if (!service && !restored)
+	{
+		gedit_main_window ();
 	}
 
 	gedit_debug_message (DEBUG_APP, "Start gtk-main");
 	gtk_main ();
 
-	/* Make sure settings are saved */
-	g_settings_sync ();
-
 	/* Cleanup */
 	g_object_unref (engine);
 	g_object_unref (app);
@@ -234,9 +227,6 @@ main (int argc, char *argv[])
 	/* Init type system as soon as possible */
 	g_type_init ();
 
-	/* Init glib threads asap */
-	g_thread_init (NULL);
-
 	/* Setup debugging */
 	gedit_debug_init ();
 	gedit_debug_message (DEBUG_APP, "Startup");
